@@ -1066,8 +1066,10 @@ class MainWindow:
     def add_ingredient_dlg(self, widget, amount, unit, ing, edit, seliter):
         if edit:
             title = "Edit ingredient"
+            btnlabel = "Edit"
         else:
             title = "Add ingredient"
+            btnlabel = "Add"
 
         dlg = gtk.Dialog(title=title, parent=None, flags=0)
         dlg.set_has_separator(False)
@@ -1095,7 +1097,7 @@ class MainWindow:
         dlg.vbox.pack_start(self.unit_btn, False, False, 0)
 
         button = hildon.Button(fhsize, horbtn)
-        button.set_label("Add")
+        button.set_label(btnlabel)
         button.connect("clicked", self.on_add_ingredient, dlg, edit, seliter)
         dlg.vbox.pack_start(button, False, False, 0)
 
