@@ -29,7 +29,12 @@ class ShopGui():
         menu.show_all()
         self.window.set_app_menu(menu)
 
-        hbox = gtk.HBox()
+        portrait = self.is_portrait()
+
+        if portrait:
+            hbox = gtk.VBox()
+        else:
+            hbox = gtk.HBox()
 
         parea = hildon.PannableArea()
         parea.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
@@ -46,7 +51,11 @@ class ShopGui():
 
         hbox.pack_start(parea, True, True, 0)
 
-        vbox = gtk.VBox()
+        if portrait:
+            vbox = gtk.HBox()
+        else:
+            vbox = gtk.VBox()
+
         vbox.set_homogeneous(True)
 
         button = hildon.Button(autosize, horbtn)
@@ -90,6 +99,14 @@ class ShopGui():
         self.window.add(hbox)
         self.window.show_all()
 
+    def is_portrait(self):
+        width = gtk.gdk.screen_width()
+        height = gtk.gdk.screen_height()
+        if width > height:
+            return False
+        else:
+            return True
+
     #Show the window if it's hidden.
     def show(self):
         self.window.show()
@@ -228,7 +245,9 @@ class ShopGui():
 
     #Clear completely the shopping list
     def clear_shoplist(self, widget):
-        self.shoplist_model.clear()
+        conf = pyrecipe_utils.on_confirmation(self.window, "Clear shopping list?")
+        if conf:
+            self.shoplist_model.clear()
 
     #Mark or unmark a shopped item.
     def mark_item_as_bought(self, widget):
